#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QTabWidget>
#include <QtGui/QSystemTrayIcon>
#include <QHostInfo>

class QScriptEngine;

class HasherThread;

namespace Ui {
    class MainView;
}

class MainView : public QTabWidget {
    Q_OBJECT
public:
    MainView(QWidget *parent = 0);
    ~MainView();

    QString findResource( const QString &filename );

public slots:

    void trayIconActivated( QSystemTrayIcon::ActivationReason );

    bool loadScript( const QString &filename );
    void scriptEntryRun();

    void urlEncodeClipboard();
    void urlDecodeClipboard();

    void urlEncodeText();
    void urlDecodeText();

    void base64EncodeText();
    void base64DecodeText();

    void hexEncodeText();
    void hexDecodeText();

    void lookup();
    void lookupClipboard();
    void lookup( const QString &thing );

    void lookupIpAddress( const QString &ip );
    void lookupDomain( const QString &domain );
    void lookupMacAddress( const QString &mac );
    void lookupCIDR( const QString &cidr );

    void hashPressed();

protected slots:
    void lookupDomainComplete( QHostInfo info );

protected:
    void closeEvent( QCloseEvent *ev );

private:
    void setupInterpreter();
    void createTrayIcon();
    void createAsciiTable();
    void createScriptPage();
    void createLookupPage();
    void setupHashPage();

private:
    Ui::MainView *ui;
    QScriptEngine *scriptEngine;
    HasherThread *hasher;
};

#endif // MAINWINDOW_H
